@@ -3,6 +3,7 @@
 #' Convert a table from FLR format to TAF format.
 #'
 #' @param x a table of class \code{FLQuant}.
+#' @param colname a column name to use if the FLR table contains only one row.
 #'
 #' @return A data frame in TAF format.
 #'
@@ -24,9 +25,18 @@
 #'                     unit="unique", season="all", area="unique", iter=1)
 #' flr2taf(x)
 #'
+#' x1 <- x[1,,,,,,drop=FALSE]
+#' flr2taf(x1)
+#' flr2taf(x1, "Juveniles")
 #' @export
 
-flr2taf <- function(x)
+flr2taf <- function(x, colname="Value")
 {
-  xtab2taf(as.data.frame(t(drop(unclass(x)))))
+  y <- xtab2taf(as.data.frame(t(drop(unclass(x)))))
+  if(nrow(y) == 1)
+  {
+    y <- data.frame(Year=simplify(names(y[-1])), Value=unname(t(y[-1])))
+    names(y)[2] <- colname
+  }
+  y
 }
