@@ -7,10 +7,8 @@
 #' @return Logical vector, indicating which scripts ran without errors.
 #'
 #' @note
-#' TAF scripts that will be run if they exist: \verb{data.R}, \verb{input.R},
-#' \verb{model.R}, \verb{output.R}, and \verb{report.R}.
-#'
-#' If a \verb{begin.R} script exists, it is ignored.
+#' TAF scripts that will be run if they exist: \verb{data.R}, \verb{model.R},
+#' \verb{output.R}, and \verb{report.R}.
 #'
 #' @seealso
 #' \code{\link{sourceTAF}} runs a TAF script.
@@ -30,7 +28,7 @@
 
 sourceAll <- function(...)
 {
-  scripts <- c("data.R", "input.R", "model.R", "output.R", "report.R")
+  scripts <- c("data.R", "model.R", "output.R", "report.R")
   scripts <- scripts[file.exists(scripts)]
 
   ok <- sapply(scripts, sourceTAF, ...)
